@@ -1,5 +1,7 @@
 from pyraphtory._config import jars, java, java_args
+from pyraphtory import __version__
 import subprocess
+import sys
 
 
 def standalone():
@@ -9,5 +11,13 @@ def standalone():
         subprocess.run([java, "-cp", jars, "com.raphtory.service.Standalone"])
 
 
+def classpath():
+    sys.stdout.write(jars)
+
+
+def version():
+    sys.stdout.write(__version__)
+
+
 if __name__ == "__main__":
     standalone()
